@@ -1,6 +1,6 @@
-// $Id: file.cc 2849 2009-09-01 10:50:34Z rafi $
+// $Id: file.cc 3351 2010-09-17 21:55:30Z java $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -75,15 +75,6 @@
 
 #ifdef HAVE_ALLOCA_H
 # include <alloca.h>
-#elif defined __GNUC__
-# define alloca __builtin_alloca
-#elif defined _AIX
-# define alloca __alloca
-#elif defined _MSC_VER
-# include <malloc.h>
-# define alloca _alloca
-#else
-# include <stddef.h>
 #endif
 
 using namespace YAPET;
