@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: colors.h 2719 2009-08-20 01:30:25Z rafi $
+// $Id: colors.h 3368 2010-09-19 12:34:28Z java $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -38,6 +38,13 @@
 #endif // HAVE_NCURSES_H
 #include "curswa.h" // Leave this here. It depends on the above includes.
 
+#ifdef __CYGWIN__
+// Cygwin #defines COLORS which leads to compile errors.
+# ifdef COLORS
+#  undef COLORS
+# endif
+#endif
+
 namespace YAPET {
     namespace UI {
         /**
