@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: curswa.h 2736 2009-08-20 19:58:47Z rafi $
+// $Id: curswa.h 3351 2010-09-17 21:55:30Z java $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -93,7 +93,9 @@ enum {
      */
     KEY_SPACE = ' ',
 #endif // KEY_SPACE
-    SPACER_TO_AVOID_COMPILER_WARNINGS
+    /* Used by InputWidget to indicate that the read-only mode should be
+       left */
+    KEY_CTRL_E = 5
 };
 
 /**
@@ -220,19 +222,6 @@ inline int mvwaddnstr_c (WINDOW* win, int y, int x, const char* str, int n) {
 
 #ifdef HAVE_ALLOCA_H
 # include <alloca.h>
-#elif defined __GNUC__
-# define alloca __builtin_alloca
-#elif defined _AIX
-# define alloca __alloca
-#elif defined _MSC_VER
-# include <malloc.h>
-# define alloca _alloca
-#else
-# include <stddef.h>
-# ifdef  __cplusplus
-extern "C"
-# endif
-void *alloca (size_t);
 #endif
 
 inline int _mvwchgat_ (WINDOW* w, int y, int x, int n, int attr, short color, const void*) {
