@@ -1,6 +1,6 @@
-// $Id: inputwidget.cc 2764 2009-08-21 20:00:05Z rafi $
+// $Id: inputwidget.cc 3354 2010-09-18 21:03:54Z rafi $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -75,10 +75,10 @@ InputWidget::moveEnd() throw (UIException) {
     refresh();
 }
 
-
 void
 InputWidget::processInput (int ch) throw (UIException) {
     if (buffer.length() + 1 > ( (secstring::size_type) max_length) ) return;
+    if (readonly) return;
 
     if ( ( (secstring::size_type) start_pos + pos) > buffer.length() )
         buffer.append ("" + ch);
@@ -93,6 +93,7 @@ InputWidget::processInput (int ch) throw (UIException) {
 void
 InputWidget::processBackspace() throw (UIException) {
     if (pos + start_pos == 0) return;
+    if (readonly) return;
 
     moveBackward();
     processDelete();
@@ -101,6 +102,7 @@ InputWidget::processBackspace() throw (UIException) {
 void
 InputWidget::processDelete() throw (UIException) {
     if ( ( (secstring::size_type) pos + start_pos) == buffer.length() ) return;
+    if (readonly) return;
 
     buffer.erase (pos + start_pos, 1);
 
@@ -141,13 +143,25 @@ InputWidget::createWindow (int sx, int sy, int w) throw (UIException) {
     //refresh();
 }
 
-InputWidget::InputWidget (int sx, int sy, int w, int ml)
+InputWidget::InputWidget (int sx, int sy, int w, int ml, bool ro)
 throw (UIException) : window (NULL),
-        max_length (ml),
-        start_pos (0),
-        pos (0),
-        width (w),
-        text_changed (false) {
+		      max_length (ml),
+		      start_pos (0),
+		      pos (0),
+		      width (w),
+		      text_changed (false),
+		      readonly (ro) {
+    createWindow (sx, sy, w);
+}
+
+InputWidget::InputWidget (int sx, int sy, int w, bool ro)
+throw (UIException) : window (NULL),
+		      max_length (DEFAULT_TEXT_LEN),
+		      start_pos (0),
+		      pos (0),
+		      width (w),
+		      text_changed (false),
+		      readonly (ro) {
     createWindow (sx, sy, w);
 }
 
@@ -184,11 +198,12 @@ InputWidget::focus() throw (UIException) {
         switch (ch) {
                 // Bailout keys
 #ifdef HAVE_WRESIZE
-            case KEY_RESIZE:
+	    case KEY_RESIZE:
 #endif // HAVE_WRESIZE
             case '\n':
             case KEY_TAB:
             case KEY_ESC:
+	    case KEY_CTRL_E:
                 goto BAILOUT;
                 // Motion and other keys
             case KEY_UP:
