@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: inputwidget.h 2719 2009-08-20 01:30:25Z rafi $
+// $Id: inputwidget.h 3342 2010-09-17 18:32:00Z java $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -42,6 +42,10 @@
 # include <string>
 #endif
 
+#ifdef HAVE_STDEXCEPT
+# include <stdexcept>
+#endif
+
 #include "uiexception.h"
 #include "secstring.h"
 
@@ -69,6 +73,18 @@ namespace YAPET {
                 int pos;
                 int width;
                 bool text_changed;
+		bool readonly;
+
+		/**
+		 * Using the default constructor will lead to SIGSEGV. This is
+		 * due to the way we handle initialization of curses stuff.
+		 *
+		 * You will have to explicitely write every constructor as
+		 * shown below.
+		 */
+		inline InputWidget() throw (std::runtime_error) {
+		    throw std::runtime_error(_("Default constructor must not be used!"));
+		}
 
                 inline InputWidget (const InputWidget&) {}
                 inline const InputWidget& operator= (const InputWidget&) {
@@ -80,6 +96,10 @@ namespace YAPET {
                 void moveHome() throw (UIException);
                 void moveEnd() throw (UIException);
 
+		enum {
+		    DEFAULT_TEXT_LEN=512
+		};
+
             protected:
                 virtual void processBackspace() throw (UIException);
                 virtual void processDelete() throw (UIException);
@@ -108,7 +128,9 @@ namespace YAPET {
                 }
 
             public:
-                InputWidget (int sx, int sy, int w, int ml = 512) throw (UIException);
+                InputWidget (int sx, int sy, int w, int ml = DEFAULT_TEXT_LEN, bool ro = false) throw (UIException);
+                InputWidget (int sx, int sy, int w, bool ro) throw (UIException);
+
                 virtual ~InputWidget();
 
                 virtual int focus() throw (UIException);
@@ -133,7 +155,12 @@ namespace YAPET {
                 inline bool hasText() const {
                     return !buffer.empty();
                 }
-
+		inline void setReadonly(bool ro) {
+		    readonly = ro;
+		}
+		inline bool getReadonly() const {
+		    return readonly;
+		}
         };
 
     }
