@@ -1,6 +1,6 @@
-// $Id: main.cc 2890 2009-09-03 10:27:30Z rafi $
+// $Id: main.cc 3356 2010-09-18 21:06:17Z rafi $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -103,20 +103,20 @@
  */
 
 const char COPYRIGHT[] = "YAPET -- Yet Another Password Encryption Tool\n" \
-                         "Copyright (C) 2008, 2009  Rafael Ostertag\n"               \
-                         "\n"                                \
-                         "This program is free software: you can redistribute it and/or modify\n" \
-                         "it under the terms of the GNU General Public License as published by\n" \
-                         "the Free Software Foundation, either version 3 of the License, or\n" \
-                         "(at your option) any later version.\n"             \
-                         "\n"                                \
-                         "This program is distributed in the hope that it will be useful,\n" \
-                         "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"  \
-                         "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"   \
-                         "GNU General Public License for more details.\n"            \
-                         "\n"                                \
-                         "You should have received a copy of the GNU General Public License\n" \
-                         "along with this program.  If not, see <http://www.gnu.org/licenses/>.\n";
+			 "Copyright (C) 2008-2010  Rafael Ostertag\n"               \
+			 "\n"                                \
+			 "This program is free software: you can redistribute it and/or modify\n" \
+			 "it under the terms of the GNU General Public License as published by\n" \
+			 "the Free Software Foundation, either version 3 of the License, or\n" \
+			 "(at your option) any later version.\n"             \
+			 "\n"                                \
+			 "This program is distributed in the hope that it will be useful,\n" \
+			 "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"  \
+			 "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"   \
+			 "GNU General Public License for more details.\n"            \
+			 "\n"                                \
+			 "You should have received a copy of the GNU General Public License\n" \
+			 "along with this program.  If not, see <http://www.gnu.org/licenses/>.\n";
 
 
 void set_rlimit() {
@@ -127,26 +127,26 @@ void set_rlimit() {
     int retval = setrlimit (RLIMIT_CORE, &rl);
 
     if (retval != 0) {
-        std::cerr << _ ("Failed to suppress the creation of core file.")
-                  << std::endl
-                  << _ ("The error message is: ") << strerror (errno)
-                  << std::endl
-                  << _ ("In case a core file is created, it may contain clear text passwords.")
-                  << std::endl
-                  << std::endl
-                  << _ ("Press <ENTER> to continue")
-                  << std::endl;
-        std::cin.ignore(1,'\n');
+	std::cerr << _ ("Failed to suppress the creation of core file.")
+		  << std::endl
+		  << _ ("The error message is: ") << strerror (errno)
+		  << std::endl
+		  << _ ("In case a core file is created, it may contain clear text passwords.")
+		  << std::endl
+		  << std::endl
+		  << _ ("Press <ENTER> to continue")
+		  << std::endl;
+	std::cin.ignore(1,'\n');
     }
 
 #else
     std::cerr << _ ("Cannot suppress the creation of core file.")
-              << std::endl
-              << _ ("In case a core file is created, it may contain clear text passwords.")
-              << std::endl
-              << std::endl
-              << _ ("Press <ENTER> to continue")
-              << std::endl;
+	      << std::endl
+	      << _ ("In case a core file is created, it may contain clear text passwords.")
+	      << std::endl
+	      << std::endl
+	      << _ ("Press <ENTER> to continue")
+	      << std::endl;
     std::cin.ignore(1,'\n');
 #endif
 }
@@ -203,50 +203,50 @@ void show_help (char* prgname) {
     show_version();
     std::cout << std::endl;
     std::cout << prgname
-              << " [-chV] [-i | -r <rcfile>] [-s | -S] [-t <sec>] [<filename>]"
-              << std::endl
-              << std::endl;
+	      << " [-chV] [-i | -r <rcfile>] [-s | -S] [-t <sec>] [<filename>]"
+	      << std::endl
+	      << std::endl;
     std::cout << "-c, --copyright\t\t" << _ ("show copyright information")
-              << std::endl
-              << std::endl;
+	      << std::endl
+	      << std::endl;
     std::cout << "-h, --help\t\t" << _ ("show this help text")
-              << std::endl
-              << std::endl;
+	      << std::endl
+	      << std::endl;
     std::cout << "-i, --ignore-rc\t\t" << _ ("do not read the configuration file.")
-              << std::endl
-              << std::endl;
+	      << std::endl
+	      << std::endl;
     std::cout << "-r, --rc-file\t\t" << _ ("read the configuration file specified by <rcfile>.\n" \
-                                           "\t\t\tIf this option is not provided, it defaults to\n" \
-                                           "\t\t\t$HOME/.yapet unless -i is specified.")
-              << std::endl
-              << std::endl;
+					   "\t\t\tIf this option is not provided, it defaults to\n" \
+					   "\t\t\t$HOME/.yapet unless -i is specified.")
+	      << std::endl
+	      << std::endl;
     std::cout << "-s, --no-file-security\t" << _ ("disable check of owner and file permissions.\n" \
-              "\t\t\tWhen creating new files, the file mode is set\n" \
-              "\t\t\tto 0644.")
-              << std::endl
-              << std::endl;
+	      "\t\t\tWhen creating new files, the file mode is set\n" \
+	      "\t\t\tto 0644.")
+	      << std::endl
+	      << std::endl;
     std::cout << "-S, --file-security\t" << _ ("enable check of owner and file permissions.\n" \
-              "\t\t\tWhen creating new files, the file mode is set\n" \
-              "\t\t\tto 0600.")
-              << std::endl
-              << std::endl;
+	      "\t\t\tWhen creating new files, the file mode is set\n" \
+	      "\t\t\tto 0600.")
+	      << std::endl
+	      << std::endl;
     std::cout << "-t, --timeout\t\t" << _ ("the time-out in seconds until the screen is locked.\n" \
-                                           "\t\t\tDefault: 600 sec.")
-              << std::endl
-              << std::endl;
+					   "\t\t\tDefault: 600 sec.")
+	      << std::endl
+	      << std::endl;
     std::cout << "-V, --version\t\t" << _ ("show the version of ") << PACKAGE_NAME
-              << std::endl
-              << std::endl;
+	      << std::endl
+	      << std::endl;
     std::cout << "<filename>\t\t" << _ ("open the specified file <filename>")
-              << std::endl
-              << std::endl;
+	      << std::endl
+	      << std::endl;
     char buff[512];
     snprintf (buff, 512, _ ("%s stores passwords encrypted on disk using the blowfish encryption\n" \
-                            "algorithm. Point your browser to http://www.guengel.ch/myapps/yapet/\n"
-                            "for more information about %s."), PACKAGE_NAME, PACKAGE_NAME);
+			    "algorithm. Point your browser to http://www.guengel.ch/myapps/yapet/\n"
+			    "for more information about %s."), PACKAGE_NAME, PACKAGE_NAME);
     std::cout << buff
-              << std::endl
-              << std::endl;
+	      << std::endl
+	      << std::endl;
 }
 
 int main (int argc, char** argv) {
@@ -262,15 +262,15 @@ int main (int argc, char** argv) {
     int c;
 #ifdef HAVE_GETOPT_LONG
     struct option long_options[] = {
-        { (char*) "copyright", no_argument, NULL, 'c'},
-        { (char*) "help", no_argument, NULL, 'h'},
-        { (char*) "ignore-rc", no_argument, NULL, 'i'},
-        { (char*) "rc-file", required_argument, NULL, 'r'},
-        { (char*) "no-file-security", no_argument, NULL, 's'},
-        { (char*) "file-security", no_argument, NULL, 'S'},
-        { (char*) "timeout", required_argument, NULL, 't'},
-        { (char*) "version", no_argument, NULL, 'V'},
-        {NULL, 0, NULL, 0}
+	{ (char*) "copyright", no_argument, NULL, 'c'},
+	{ (char*) "help", no_argument, NULL, 'h'},
+	{ (char*) "ignore-rc", no_argument, NULL, 'i'},
+	{ (char*) "rc-file", required_argument, NULL, 'r'},
+	{ (char*) "no-file-security", no_argument, NULL, 's'},
+	{ (char*) "file-security", no_argument, NULL, 'S'},
+	{ (char*) "timeout", required_argument, NULL, 't'},
+	{ (char*) "version", no_argument, NULL, 'V'},
+	{NULL, 0, NULL, 0}
     };
 
     while ( (c = getopt_long (argc, argv, ":chir:sSt:V", long_options, NULL) ) != -1) {
@@ -281,46 +281,46 @@ int main (int argc, char** argv) {
     while ( (c = getopt (argc, argv, ":c(copyright)h(help)i(ignore-rc)r:(rc-file)s(no-file-security)S(file-security)t:(timeout)V(version)") ) != -1) {
 #endif // HAVE_GETOPT_LONG
 
-        switch (c) {
-            case 'c':
-                show_copyright();
-                return 0;
-            case 'h':
-                show_help (argv[0]);
-                return 0;
-            case 'i':
-                config.setIgnorerc (true);
-                break;
-            case 'r':
-                cfgfilepath = optarg;
-                break;
-            case 'V':
-                show_version();
-                return 0;
-            case 's':
-                config.setFilesecurity (false);
-                break;
-            case 'S':
-                config.setFilesecurity (true);
-                break;
-            case 't':
-                unsigned int timeout;
-                sscanf (optarg, "%u", &timeout);
-                config.setTimeout (timeout);
-                break;
-            case ':':
-                std::cerr << "-" << (char) optopt << _ (" without argument")
-                          << std::endl;
-                return 1;
-            case '?':
-                std::cerr << _ ("unknown argument") << " '" << (char) optopt << "'"
-                          << std::endl;
-                return 1;
-        }
+	switch (c) {
+	    case 'c':
+		show_copyright();
+		return 0;
+	    case 'h':
+		show_help (argv[0]);
+		return 0;
+	    case 'i':
+		config.setIgnorerc (true);
+		break;
+	    case 'r':
+		cfgfilepath = optarg;
+		break;
+	    case 'V':
+		show_version();
+		return 0;
+	    case 's':
+		config.setFilesecurity (false);
+		break;
+	    case 'S':
+		config.setFilesecurity (true);
+		break;
+	    case 't':
+		unsigned int timeout;
+		sscanf (optarg, "%u", &timeout);
+		config.setTimeout (timeout);
+		break;
+	    case ':':
+		std::cerr << "-" << (char) optopt << _ (" without argument")
+			  << std::endl;
+		return 1;
+	    case '?':
+		std::cerr << _ ("unknown argument") << " '" << (char) optopt << "'"
+			  << std::endl;
+		return 1;
+	}
     }
 
     if (optind < argc) {
-        config.setPetFile (argv[optind]);
+	config.setPetFile (argv[optind]);
     }
 
     config.loadConfigFile (cfgfilepath);
@@ -329,31 +329,41 @@ int main (int argc, char** argv) {
     std::string _tmp__ = config.getPetFile();
 #endif
     assert (_tmp__.empty() ||
-            _tmp__.find (YAPET::CONSTS::Consts::getDefaultSuffix(),
-                         _tmp__.length() -
-                         YAPET::CONSTS::Consts::getDefaultSuffix().length() )
-            != std::string::npos);
+	    _tmp__.find (YAPET::CONSTS::Consts::getDefaultSuffix(),
+			 _tmp__.length() -
+			 YAPET::CONSTS::Consts::getDefaultSuffix().length() )
+	    != std::string::npos);
     // Make sure we have a cleaned up file path
     assert (_tmp__.find ("//", 0) == std::string::npos);
 #ifndef CFGDEBUG
-    YAPET::UI::BaseWindow::initCurses();
+    try {
+	YAPET::UI::BaseWindow::initCurses();
+    } catch (YAPET::UI::UIException &ex) {
+	YAPET::UI::BaseWindow::endCurses();
+	std::cerr << ex.what() << std::endl;
+	return 1;
+    }
     MainWindow* mainwin = NULL;
 
-    try {
-	YAPET::GLOBALS::Globals::setPWGenRNG(config.getPWGenRNG());
-	YAPET::GLOBALS::Globals::setCharacterPools(config.getCharPools());
-	YAPET::GLOBALS::Globals::setPasswordLength(config.getPWGenPWLen());
-        mainwin = new MainWindow (config.getTimeout(), config.getFilesecurity() );
-        // filename may be empty
-        mainwin->run (config.getPetFile() );
-        delete mainwin;
-    } catch (std::exception& ex) {
-        if (mainwin != NULL)
-            delete mainwin;
+    YAPET::GLOBALS::Globals::setPWGenRNG(config.getPWGenRNG());
+    YAPET::GLOBALS::Globals::setCharacterPools(config.getCharPools());
+    YAPET::GLOBALS::Globals::setPasswordLength(config.getPWGenPWLen());
+    YAPET::GLOBALS::Globals::setAllowLockQuit(config.getAllowLockQuit());
+    YAPET::GLOBALS::Globals::setPwInputTimeout(config.getPwInputTimeout());
 
-        YAPET::UI::BaseWindow::endCurses();
-        std::cerr << ex.what() << std::endl << std::endl;
-        return 1;
+    try {
+
+	mainwin = new MainWindow (config.getTimeout(), config.getFilesecurity() );
+	// filename may be empty
+	mainwin->run (config.getPetFile() );
+	delete mainwin;
+    } catch (std::exception& ex) {
+	if (mainwin != NULL)
+	    delete mainwin;
+
+	YAPET::UI::BaseWindow::endCurses();
+	std::cerr << ex.what() << std::endl << std::endl;
+	return 1;
     }
 
     YAPET::UI::BaseWindow::endCurses();
