@@ -1,6 +1,6 @@
-// $Id: mainwindow.cc 2824 2009-08-31 17:46:39Z rafi $
+// $Id: mainwindow.cc 3356 2010-09-18 21:06:17Z rafi $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -71,6 +71,7 @@
 #ifdef ENABLE_PWGEN
 # include "pwgendialog.h"
 #endif
+#include "globals.h"
 
 /**
  * @brief Structure defining a key for the \c MainWindow.
@@ -622,7 +623,8 @@ MainWindow::addNewRecord() {
     PasswordRecord* pwentry = NULL;
 
     try {
-        pwentry = new PasswordRecord (*key, NULL);
+	// Open the dialog in read-write mode by default
+        pwentry = new PasswordRecord (*key, NULL, false);
         pwentry->run();
 
         if (pwentry->entryChanged() &&
@@ -673,7 +675,8 @@ MainWindow::editSelectedRecord() {
 
     try {
         YAPET::PartDec pd = recordlist->getSelectedItem();
-        pwentry = new PasswordRecord (*key, &pd);
+	// Open the dialog in read-only mode by default
+        pwentry = new PasswordRecord (*key, &pd, true);
         pwentry->run();
 
         if (pwentry->entryChanged() &&
@@ -922,11 +925,23 @@ MainWindow::lockScreen() const throw (YAPET::UI::UIException) {
 #endif
         PasswordDialog* pwdia = NULL;
         YAPET::Key* testkey = NULL;
+	bool wants_quit = false;
 
         try {
-            pwdia = new PasswordDialog (EXISTING_PW, file->getFilename() );
+	    // Flush pending input
+	    flushinp();
+
+	    bool show_quit = records_changed ? false : true;
+	    // In case the user does not want to show the quit button
+	    show_quit = YAPET::GLOBALS::Globals::getAllowLockQuit() ? show_quit : false;
+
+            pwdia = new PasswordDialog (EXISTING_PW,
+					file->getFilename(),
+					YAPET::GLOBALS::Globals::getPwInputTimeout(),
+					show_quit);
             pwdia->run();
             testkey = pwdia->getKey();
+	    wants_quit = pwdia->wantsQuit();
             delete pwdia;
         } catch (YAPET::UI::UIException&) {
             if (pwdia != NULL)
@@ -941,6 +956,11 @@ MainWindow::lockScreen() const throw (YAPET::UI::UIException) {
 
         if (testkey == NULL) {
             delwin (lockwin);
+	    // Do we have to quit
+	    if (wants_quit) {
+		ungetch('q');
+		return;
+	    }
             continue;
         }
 
@@ -1131,7 +1151,6 @@ MainWindow::run() throw (YAPET::UI::UIException) {
                     case 3: // ^C
                     case 'Q':
                     case 'q':
-
                         if (quit() ) return;
 
                         break;
@@ -1260,7 +1279,6 @@ MainWindow::run() throw (YAPET::UI::UIException) {
                                 delete tmp;
                         }
 
-			//                        ::refresh();
                         YAPET::UI::BaseWindow::refreshAll();
                         break;
                     }
