@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: passwordrecord.h 2719 2009-08-20 01:30:25Z rafi $
+// $Id: passwordrecord.h 3342 2010-09-17 18:32:00Z java $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -102,12 +102,15 @@ class PasswordRecord : protected YAPET::UI::BaseWindow {
         bool usernamechanged;
         bool passwordchanged;
         bool commentchanged;
+	bool readonly;
 
         inline PasswordRecord (const PasswordRecord&) {}
         inline const PasswordRecord& operator= (const PasswordRecord&) {
             return *this;
         }
 
+    protected:
+
         inline int getWidth() const {
             return maxX() - 8;
         }
@@ -142,7 +145,7 @@ class PasswordRecord : protected YAPET::UI::BaseWindow {
          * @param pe pointer to a \c PartDec which will be displayed, or \c
          * NULL in order to obtain a new password record.
          */
-        PasswordRecord (YAPET::Key& k, YAPET::PartDec* pe) throw (YAPET::UI::UIException);
+        PasswordRecord (YAPET::Key& k, YAPET::PartDec* pe, bool ro = false) throw (YAPET::UI::UIException);
         ~PasswordRecord();
 
         /**
@@ -179,6 +182,10 @@ class PasswordRecord : protected YAPET::UI::BaseWindow {
          * @return \c true if the record has been changed, \c false otherwise.
          */
         bool entryChanged() const;
+
+	void setReadonly(bool ro);
+
+	inline bool getReadonly() const { return readonly; }
 };
 
 #endif // _PASSWORDRECORD_H
